<?php

declare(strict_types=1);

namespace Apexl\Io\Cache;

use Apexl\Io\Cache\Hooks\RegisterDefaultCacheStreams;
use apexl\Io\includes\Module;
use app\vendor\apexl\io\src\Io\interfaces\ProvidesHooksInterface;

final class CacheModule extends Module implements ProvidesHooksInterface
{
    public function hooks(): array
    {
        return [
            RegisterDefaultCacheStreams::class,
        ];
    }
}