<?php

declare(strict_types=1);

use Apexl\Io\Cache\Interfaces\CacheManagerInterface;
use Apexl\Io\Cache\Interfaces\CacheStreamInterface;
use Apexl\Io\Cache\Services\CacheManager;
use Apexl\Io\Cache\Services\CacheStream;
use function DI\autowire;
use function DI\factory;

return [
    CacheManagerInterface::class => autowire(CacheManager::class),
    CacheStreamInterface::class => autowire(CacheStream::class),
    'cache.default' => factory(fn(CacheManagerInterface $cacheManager) => $cacheManager->default())
];